#! /usr/bin/perl -w

#
# Operazioni preliminari.
#
open(INPUT,$ARGV[0]) || die "Problemi con il file $ARGV[0]";

$nomeA = $ARGV[1] || die "Primo nome assente"; 
$nomeB = $ARGV[2] || die "Secondo nome assente";

#
# Primo ciclo di lettura, si legge il file rigo per rigo, 
# che viene modificato e salvato in @nuoviValori
#
# Il programma funziona assumendo che $nomeA e $nomeB compaiano 
# entrambi una sola volta nel file di input.
#
while (<INPUT>)
{
	#
	# Caso 1, nel rigo compare $nomeA, ma non $nomeB
	# 
	if (/\|$nomeA\|/ && !/\|$nomeB\|/)
	{
		#
		# Rimpiazzo |$nomeA| con |$nomeB|. 
		# Si noti che il carattere '|'  speciale nella prima parte dell' espressione.
		# Va usato come '\|' nella prima espressione, ma va bene come '|' nella seconda 
		#
		# L'espressione di sostituzione  nel formato s[ valoreCercato ][ valoreDaSostituire ]
		#
		s[\|$nomeA\|][|$nomeB|];
	}
	#
	# Caso 2, nel rigo compare $nomeB, ma non $nomeA. Simmetrico al precedente.
	#
	elsif (/\|$nomeB\|/ && !/\|$nomeA\|/)
	{
		s[\|$nomeB\|][|$nomeA|];
	};
	#
	# Caso 3, nel rigo compaiono ENTRAMBI i nomi
	# Bisogna scambiarli.
	#
	#
	# L'espressione regolare che segue verifica che che compaia nel rigo |$nomeA| oppure |$nomeB|,
	# seguito da |$nomeA| oppure |$nomeB|  
    #
    # (si noti che non pu mai succedere che $nomeA compaia due volte nello stesso rigo, e per $nomeB
    #  vale la stessa cosa )
	#
	if (/\|($nomeB|$nomeA)\|.*\|($nomeB|$nomeA)\|/)
	{
		#
		# Memorizzo in $A e $B le variabili $1 e $2 
		# ($1 verr sovrascritta nell'istruzione successiva)
		# In $A finisce la prima occorrenza di nome cercato (che pu essere o $nomeA o $nomeB)
		# In $B finisce l'altra occorrenza (che dovrebbe essere l'altro nome)
		#
        $A = $1; 
        $B = $2;	
        #
        # Cerco ora nel rigo '|$A' seguito da |.*| (memorizzato in $1), 
        # seguito da '$B|', e lo rimpiazzo con |$B$1$A| (scambio $B e $A, lasciando cio' che
        # c' in mezzo invariati.)
        #
		s[\|$A(\|.*\|)$B\|][|$B$1$A|];
	};
    #
    # Appendo $_ (eventualmente modificata) a @nuovivalori.
    # 
	push @nuoviValori, $_;
}
#
# Chiudo il file appena letto.
#
close INPUT;

#
# Lo riapro in scrittura
#
open(OUTPUT,">$ARGV[0]") || die "$ARGV[0] non pu essere aperto in scrittura";
#
# Ci stampo tutto @nuovivalori dentro.
#
print OUTPUT foreach (@nuoviValori);
#
# Chiudo.
#
close OUTPUT;

